@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2017 by Peter Semiletov <peter.semiletov@gmail.com>                            *
+ *   2007-2018 by Peter Semiletov <peter.semiletov@gmail.com>                            *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -37,29 +37,28 @@ code from qwriter:
 #define DOCUMENT_H
 
 
-#include "logmemo.h"
-#include "tio.h"
-#include "todo.h"
-
-
 #include <QPoint>
-
 #include <QStatusBar>
 #include <QMainWindow>
 #include <QTabWidget>
 #include <QPlainTextEdit>
 #include <QSyntaxHighlighter>
-//#include <QDebug>
 
 #if QT_VERSION >= 0x050000
-
 #include <QRegularExpression>
-
 #endif
 
+#if defined(Q_OS_UNIX)
+#include "myjoystick.h"
+#endif
+
+#include "logmemo.h"
+#include "tio.h"
+#include "todo.h"
+
 
 class LineNumberArea;
-class document_holder;
+class CDox;
 class CDocument;
 
 
@@ -67,22 +66,18 @@ class CTEAEdit: public QPlainTextEdit
 {
   Q_OBJECT
   
-
 public:
 
   QString indent_val;  
   QList <QTextEdit::ExtraSelection> extraSelections;
   QTextEdit::ExtraSelection brace_selection;
-
   
-  //rect selection
-
-  QPoint rect_sel_start;
-  QPoint rect_sel_end;
+  QPoint rect_sel_start; //rect selection
+  QPoint rect_sel_end;   //rect selection
  
-  CDocument *doc;
+  CDocument *doc; //uplink
 
-  QColor currentLineColor;
+  QColor current_line_color;
   QColor brackets_color;
   QColor margin_color;
   QColor linenums_bg;
@@ -91,10 +86,9 @@ public:
   QColor sel_text_color;
   QColor sel_back_color;
 
-
   QWidget *lineNumberArea;
 
-  bool highlightCurrentLine;
+  bool highlight_current_line;
   bool hl_brackets;
   bool draw_margin;
   bool draw_linenums;
@@ -107,13 +101,11 @@ public:
   int tab_sp_width; //in spaces
   int brace_width; //in pixels
   int margin_pos; //in chars
-  int margin_x; //in pixels
+  int margin_x;  //in pixels
 
 
   CTEAEdit (QWidget *parent = 0);
 
-  void setCurrentLineColor (const QColor &newColor);
-  void set_brackets_color (const QColor &newColor);
   void set_show_linenums (bool enable);
   void set_show_margin (bool enable);
   void set_margin_pos (int mp);
@@ -129,25 +121,16 @@ public:
 
   void rect_sel_reset();
   void rect_sel_replace (const QString &s, bool insert = false);
-  //void rect_sel_insert (const QString &s);
-  
-  
   void update_ext_selections();
-  
-  
   void update_rect_sel();
-  
   QString get_rect_sel();
-
   void rect_sel_cut (bool just_del = false);
 
-
   void braceHighlight();
   
   void lineNumberAreaPaintEvent(QPaintEvent *event);
   int lineNumberAreaWidth();
 
-
   Q_INVOKABLE bool has_rect_selection();
   
 
@@ -162,16 +145,6 @@ protected:
   void keyPressEvent (QKeyEvent *event);    
   void resizeEvent(QResizeEvent *event);
   
-  /*
- bool event(QEvent *ev) {
-        if (ev->type() == QEvent::KeyboardLayoutChange) {
-            qDebug() << "kb layout changed";
-        } else {
-            return QWidget::event(ev);
-        }
-
-    }
-*/
 public slots:
 
   void updateLineNumberAreaWidth (int newBlockCount);
@@ -179,9 +152,6 @@ public slots:
   void updateLineNumberArea (const QRect &, int);
   
   void slot_selectionChanged();
-  
- // void copy();
-  
 };
 
 
@@ -285,7 +255,7 @@ public:
   
   QString eol;
   
-  document_holder *holder;
+  CDox *holder;
   CSyntaxHighlighter *highlighter;
   CTEAEdit *textEdit;
 
@@ -320,13 +290,11 @@ public:
   Q_INVOKABLE QString get_triplex();
   Q_INVOKABLE void update_status();
   Q_INVOKABLE void update_title (bool fullname = true);
-
-
   Q_INVOKABLE void update_labels();
 };
 
 
-class document_holder: public QObject
+class CDox: public QObject
 {
   Q_OBJECT
 
@@ -336,9 +304,9 @@ public:
 
   QString fname_current_session;
 
- // QHash <QString, QString> palette;
   QHash <QString, QString> hls;
-
+  QHash <QString, QString> markup_modes;
+  
   QLabel *l_status_bar;
   QString dir_config;
 
@@ -356,41 +324,48 @@ public:
   QMenu *recent_menu;
   QStringList recent_files;
   QString recent_list_fname;
+ 
+#if defined(Q_OS_UNIX)
+  CJoystick *joystick;
+#endif 
 
+  QTimer *timer; 
   
-  ~document_holder();
+
+  CDox();
+  ~CDox();
+
+#if defined(Q_OS_UNIX)
+
+  bool event (QEvent *ev);
+  void handle_joystick_event (CJoystickAxisEvent *ev);
+
+#endif 
+  
+  void reload_recent_list();
+  void add_to_recent (CDocument *d);
+  void update_recent_menu();
+  void update_current_files_menu();
 
   Q_INVOKABLE CDocument* create_new();
   Q_INVOKABLE CDocument* open_file (const QString &fileName, const QString &codec);
   Q_INVOKABLE CDocument* open_file_triplex (const QString &triplex);
   Q_INVOKABLE CDocument* get_document_by_fname (const QString &fileName);
-
-  void reload_recent_list();
-
+  Q_INVOKABLE CDocument* get_current();
+  Q_INVOKABLE void close_by_idx (int i);
+  Q_INVOKABLE void close_current();
+  
   Q_INVOKABLE void save_to_session (const QString &fileName);
   Q_INVOKABLE void load_from_session (const QString &fileName);
   
-  //QHash <QString, QString> load_eclipse_theme_xml (const QString &fname);
-
- //void load_palette (const QString &fileName);
-
-  void close_by_idx (int i);
-  Q_INVOKABLE void close_current();
   Q_INVOKABLE void apply_settings();
   Q_INVOKABLE void apply_settings_single (CDocument *d);
 
-  void add_to_recent (CDocument *d);
-  void update_recent_menu();
-
-  void update_current_files_menu();
-
-  Q_INVOKABLE CDocument* get_current();
- 
-
 public slots:
  
   void open_recent();
   void open_current();
+ 
 };
 
 
@@ -398,26 +373,22 @@ class CLineNumberArea: public QWidget
 {
 public:
 
-  CTEAEdit *codeEditor;
+  CTEAEdit *code_editor;
 
-  CLineNumberArea (CTEAEdit *editor = 0): QWidget (editor)
-                 {
-                  codeEditor = editor;
-                 }
+  CLineNumberArea (CTEAEdit *editor = 0): QWidget (editor), code_editor (editor) {}
 
   QSize sizeHint() const {
-                          return QSize(codeEditor->lineNumberAreaWidth(), 0);
+                          return QSize(code_editor->lineNumberAreaWidth(), 0);
                          }
 
 protected:
 
   void paintEvent (QPaintEvent *event)
       {
-       codeEditor->lineNumberAreaPaintEvent (event);
+       code_editor->lineNumberAreaPaintEvent (event);
       }
 
 };
-
   
 
 #endif
