@@ -1,5 +1,5 @@
 /**************************************************************************
- *   2007-2017 by Peter Semiletov                            *
+ *   2007-2018 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,26 +23,11 @@
 #define RVLN_H
 
 
-#include "document.h"
-#include "fman.h"
-#include "calendar.h"
-#include "shortcuts.h"
-#include "img_viewer.h"
-
-
-#ifdef SPELLCHECK_ENABLE
-
-#include "spellchecker.h"
-
-#endif
-
-
 #include <QListWidget>
 #include <QComboBox>
 #include <QProgressBar>
 #include <QCheckBox>
 #include <QSpinBox>
-//#include <QToolButton>
 #include <QFontComboBox>
 #include <QSessionManager>
 #include <QApplication>
@@ -51,33 +36,34 @@
 #include <QTextBrowser>
 #include <QTranslator>
 #include <QProcess>
-//#include <QSessionManager>
-//#include <QSystemTrayIcon>
 
 
-//QML stuff
 #ifdef USE_QML_STUFF
-
 #include <QQmlEngine>
 #include <QQuickWindow>
-
 #endif
 
-//
-
-
 
 #ifdef PRINTER_ENABLE
-
 #include <QPrinter>
-
 #endif
 
 
+#include "document.h"
+#include "fman.h"
+#include "calendar.h"
+#include "shortcuts.h"
+#include "img_viewer.h"
+
+
+#ifdef SPELLCHECK_ENABLE
+#include "spellchecker.h"
+#endif
+
 
 class CMarkupPair: public QObject
 {
-  Q_OBJECT
+Q_OBJECT
 
 public:
 
@@ -85,10 +71,9 @@ public:
 };
 
 
-
 class CStrIntPair: public QObject
 {
-  Q_OBJECT
+Q_OBJECT
 
 public:
 
@@ -101,7 +86,7 @@ public:
 
 class CDarkerWindow: public QWidget
 {
-  Q_OBJECT
+Q_OBJECT
 
   QSlider *slider;
   
@@ -122,12 +107,12 @@ public slots:
 
 class CAboutWindow: public QWidget
 {
-  Q_OBJECT
-
-  QLabel *logo;
+Q_OBJECT
   
 public:
 
+  QLabel *logo;
+
   CAboutWindow();
 
 protected:
@@ -142,7 +127,7 @@ public slots:
 
 class CTextListWnd: public QWidget
 {
-  Q_OBJECT
+Q_OBJECT
 
 public:
 
@@ -158,7 +143,7 @@ protected:
 
 class rvln: public QMainWindow
 {
-  Q_OBJECT
+Q_OBJECT
 
 public:
 
@@ -166,11 +151,15 @@ public:
   ~rvln();
   
 #ifdef USE_QML_STUFF
-
   QQmlEngine *qml_engine;
 #endif
-
-  QAction *last_action;
+  
+  
+  QStringList sl_places_bmx;
+  QStringList sl_urls;
+  QStringList sl_charsets;
+  QStringList sl_last_used_charsets;
+  QStringList sl_fif_history;
   
   int fm_entry_mode; 
 
@@ -180,7 +169,8 @@ public:
   bool portable_mode;
 
   CLogMemo *log;
-  
+  QAction *last_action;
+ 
  
   CShortcuts *shortcuts;
   CFMan *fman;
@@ -195,9 +185,7 @@ public:
 #endif
 
 
-  QHash <int, QString> moon_phase_algos;
-  void create_moon_phase_algos();
-
+  
   int icon_size;
 
   bool b_preview;
@@ -208,48 +196,30 @@ public:
   int idx_tab_tune;
   int idx_tab_fman;
   int idx_tab_learn;
-  
   int idx_tab_keyboard;
-
-
   int idx_prev;
-  
+ 
   int fman_find_idx;
   QList <QStandardItem *> l_fman_find;
   
   bool ui_update;
+
   QString fname_storage_file;
+  QString fname_stylesheet; 
+  QString man_search_value;
+  QString markup_mode;
 
   QHash <QString, CMarkupPair*> hs_markup;
-
-  QToolBar *tb_fman_dir;
-  QLabel *l_fman_preview;
- 
-  QStringList sl_places_bmx;
-  QStringList sl_urls;
-  QStringList sl_charsets;
-  QStringList sl_last_used_charsets;
-  QStringList sl_fif_history;
-
   QHash <QString, QString> programs;
   QHash <QString, QString> places_bookmarks;
-
+  QHash <int, QString> moon_phase_algos;
+  
   QTranslator myappTranslator;
   QTranslator qtTranslator;
 
   QDir dir_lv;
 
-  QComboBox *cmb_fif;
-  
-
-  //QString stylesheet; 
-  QString fname_stylesheet; 
-
-
-  QString man_search_value;
-
-  QString markup_mode;
-
+ 
 #ifdef PRINTER_ENABLE
 
   QPrinter printer;
@@ -283,10 +253,6 @@ public:
   QString dir_days;
 
   QString fname_def_palette;
-  QString fname_hls_cache;
-
- // QString fname_userfonts;
-  //QList <int> userfont_ids;
 
 
   QString fname_fif;
@@ -300,12 +266,18 @@ public:
   QString fname_tempfile;
   QString fname_tempparamfile;
 
+
+  QComboBox *cmb_fif;
+  QToolBar *tb_fman_dir;
+  QLabel *l_fman_preview;
+
   QLabel *l_status;
   QProgressBar *pb_status;
   QLineEdit *ed_spellcheck_path;
   QLineEdit *ed_aspellcheck_path;
   
   QCheckBox *cb_use_qregexpsyntaxhl;
+  QCheckBox *cb_use_joystick;
 
   QCheckBox *cb_right_to_left;
 
@@ -356,8 +328,6 @@ public:
 
 protected:
 
- // void keyPressEvent (QKeyEvent *event);    
-
   void closeEvent (QCloseEvent *event);
   bool fman_tv_eventFilter (QObject *obj, QEvent *event);
 
@@ -365,20 +335,15 @@ protected:
 public slots:
 
 
-
 /*************************
 main window callbacks
 *************************/
-
- // void app_commit_data();
-
- // void slot_commitDataRequest(QSessionManager &m); 
-
+ 
   void repeat();
 
-  void receiveMessage(const QString &msg);
+  void receiveMessage (const QString &msg);
   
-  void receiveMessageShared(const QStringList& msg);
+  void receiveMessageShared (const QStringList& msg);
         
   void view_use_theme();
 
@@ -425,17 +390,22 @@ main window callbacks
   void cb_button_saves_as();
 
   void pageChanged (int index);
-  void tab_options_pageChanged (int index);
+//  void tab_options_pageChanged (int index);
+
+#ifdef PRINTER_ENABLE
 
   void file_print();
 
+#endif
+
+
   void newFile();
   void open();
   void open_at_cursor();
   void rename_selected();
 
   void file_reload();
-  void file_reload_enc_itemDoubleClicked ( QListWidgetItem *item); 
+  void file_reload_enc_itemDoubleClicked (QListWidgetItem *item); 
   void file_reload_enc();
   void file_open_bookmarks_file();
   void file_open_programs_file();
@@ -468,21 +438,16 @@ main window callbacks
   void cal_set_to_current();
   void cal_moon_mode();
   void cal_gen_mooncal();
-
   void cal_diff_days();
 
 
   void cal_remove();
-
   void fn_sum_by_last_col();
   
-
   void fn_insert_cpp();
   void fn_insert_c();
-
   void fn_insert_template_html5();
 
-
   bool save();
   bool saveAs();
 
@@ -497,7 +462,6 @@ main window callbacks
   void ed_block_copy();
   void ed_block_paste();
   void ed_block_cut();
-  
 
   void ed_copy();
   void ed_paste();
@@ -509,16 +473,11 @@ main window callbacks
 
   void ed_indent();
   void ed_unindent();
- 
   void ed_comment();
 
-//  void ed_paste_from_charset();
-
-
   void set_as_storage_file();
   void copy_to_storage_file();
   void capture_clipboard_to_storage_file();
-
   
   void upCase();
   void dnCase();
@@ -539,19 +498,15 @@ main window callbacks
   void fn_evaluate();
   void fn_sort_casecare();
   void fn_sort_casecareless();
-
   void fn_sort_casecare_sep();
-  
 
   void fn_sort_latex_table_by_col_abc();
   void fn_table_swap_cells();
   void fn_table_delete_cells();
   void fn_table_copy_cells();
-      
   
   void fn_flip_a_list();
   void fn_flip_a_list_sep();
-
   
   void fn_insert_loremipsum();
   void fn_insert_template_html();
@@ -574,8 +529,9 @@ main window callbacks
 
   void fn_rm_formatting();
   
-   void fn_rm_compress();
+  void fn_rm_compress();
  
+  void text_compare_two_strings();
   
   void fn_convert_quotes_angle();
   void fn_convert_quotes_curly();
@@ -604,9 +560,6 @@ main window callbacks
   void fn_binary_to_decimal();
   
   void remove_formatting();
-
-//  void fn_variants_callback();
-
   
 #ifdef SPELLCHECK_ENABLE
 
@@ -615,9 +568,7 @@ main window callbacks
   void fn_spell_suggest_callback();
   void fn_spell_add_to_dict();
   void fn_remove_from_dict();
-
   void fn_spell_suggest();
-
   void cmb_spellchecker_currentIndexChanged (const QString &text);
 
 #ifdef HUNSPELL_ENABLE
@@ -628,7 +579,7 @@ main window callbacks
 #ifdef ASPELL_ENABLE
 
 #if defined(Q_OS_WIN) || defined (Q_OS_OS2)
-   void pb_choose_aspell_path_clicked();
+  void pb_choose_aspell_path_clicked();
 #endif
 
 #endif
@@ -637,11 +588,8 @@ main window callbacks
 
   void scale_image();
 
-
   void search_mark_all();
   void search_unmark();
-
-
   void search_in_files_results_dclicked (QListWidgetItem *item);
   void search_in_files();
 
@@ -666,7 +614,6 @@ main window callbacks
   void mrkup_align_right();
   void mrkup_align_justify();
   
-  
   void mrkup_document_weight();
   void markup_ins_image();
   void mrkup_color();
@@ -677,7 +624,6 @@ main window callbacks
   void search_whole_words_mode();
   void search_from_cursor_mode();
 
-
   void search_find();
   void search_find_next();
   void search_find_prev();
@@ -689,7 +635,6 @@ main window callbacks
   void view_hide_error_marks();
   void view_toggle_fs();
   void view_stay_on_top();
-
   void instr_font_gallery();
   
   
@@ -710,25 +655,19 @@ main window callbacks
   void session_save_as();
 
   void main_tab_page_changed (int index);
-
-  void fn_use_table();
-
   void calendar_currentPageChanged (int year, int month);
- //void add_user_font();
-
 
   void man_find_find();
   void man_find_next();
   void man_find_prev();
 
-
   void profile_save_as();
   void fman_mk_gallery();
   void indent_by_first_line();
 
   void process_readyReadStandardOutput();
   void fn_remove_by_regexp();
-
+  void fn_use_table();
 
   void fman_naventry_confirm();
   void fman_img_conv_by_side();
@@ -743,7 +682,6 @@ main window callbacks
   void set_eol_mac();
 
   void fn_stat_words_lengths();
-
   
   void guess_enc();
 
@@ -757,15 +695,17 @@ main window callbacks
 /*************************
 prefs window callbacks
 *************************/
+#if defined(Q_OS_UNIX)
+  void cb_use_joystick_stateChanged (int state);
+#endif
 
-  void cmb_ui_langs_currentIndexChanged (const QString &text);
+//  void cmb_ui_langs_currentIndexChanged (const QString &text);
 
   void cb_altmenu_stateChanged (int state);
 
   void cmb_ui_tabs_currentIndexChanged (int i);
   void cmb_docs_tabs_currentIndexChanged (int i);
 
-
   void cmb_icon_sizes_currentIndexChanged (const QString &text);
   void cmb_tea_icons_currentIndexChanged  (const QString &text);
 
@@ -782,7 +722,6 @@ prefs window callbacks
 
   
 #ifdef USE_QML_STUFF
-  
   void fn_use_plugin();
 #endif
   
@@ -794,7 +733,6 @@ main window widgets
 
   QSplitter *mainSplitter;
   QTextBrowser *man;
- // QPlainTextEdit *log_memo;
   QString charset;
 
   QTabWidget *main_tab_widget;
@@ -813,7 +751,6 @@ main window widgets
 
 
   QMenu *menu_file_edit_bookmarks;
-
   QMenu *menu_file_configs;
   QMenu *menu_file_sessions;
   QMenu *menu_file_actions;
@@ -831,12 +768,10 @@ main window widgets
   
   
 #ifdef USE_QML_STUFF
-  
   QMenu *menu_fn_plugins;
 #endif
 
   QMenu *menu_view_themes;
-
   
   QMenu *menu_markup;
   QMenu *menu_functions;
@@ -975,10 +910,8 @@ prefs window widgets
 
 
 #ifdef SPELLCHECK_ENABLE
-
   void setup_spellcheckers();
   void create_spellcheck_menu();
-
 #endif
 
   void init_styles();
@@ -1003,16 +936,14 @@ prefs window widgets
   void update_view_hls();
   
 #ifdef USE_QML_STUFF
-    
   void update_plugins();
-
 #endif
   
   void update_themes();
 
-
   
-  void update_hls (bool force = false);
+  //void update_hls (bool force = false);
+  void update_hls_noncached();
 
   void update_tables();
   void update_scripts();
@@ -1044,7 +975,10 @@ prefs window widgets
 
   void run_unitaz (int mode);
  
- QHash <QString, QString> load_eclipse_theme_xml (const QString &fname);
+  void create_moon_phase_algos();
+
+ 
+  QHash <QString, QString> load_eclipse_theme_xml (const QString &fname);
 
   void load_palette (const QString &fileName);
 
@@ -1054,15 +988,11 @@ prefs window widgets
   void fman_convert_images (bool by_side, int value);
  
   Q_INVOKABLE QString fif_get_text();
-  
-  
-  
+   
   
   void fn_filter_delete_by_sep (bool mode);
-
+ 
   void fman_items_select_by_regexp (bool mode);
-
-   
   void fman_find();
   void fman_find_next();
   void fman_find_prev();
@@ -1073,26 +1003,18 @@ prefs window widgets
   void opt_shortcuts_find_next();
   void opt_shortcuts_find_prev();
 
-
   void idx_tab_edit_activate();
   void idx_tab_calendar_activate();
   void idx_tab_tune_activate();
   void idx_tab_fman_activate();
   void idx_tab_learn_activate();
-
   
- // void load_userfonts();
-  
-//#if QT_VERSION >= 0x050000
 #ifdef USE_QML_STUFF
-  
   void plugins_init();
   void plugins_done();
-  
 #endif  
 
   void markup_text (const QString &mode);
-  
 };
 
 
@@ -1100,21 +1022,17 @@ prefs window widgets
 
 class CQQuickWindow: public QQuickWindow
 {
-   Q_OBJECT
+Q_OBJECT
    
 public:
- 
- 
- CQQuickWindow(QWindow * parent = 0): QQuickWindow (parent)
-   {;}
- 
- QString id;
 
+  QString id;
+ 
+  CQQuickWindow (QWindow * parent = 0): QQuickWindow (parent) {}
+ 
 protected:
 
   bool event (QEvent *event);
-
-  
 };
 
 #endif
