@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2017 by Peter Semiletov                                          *
+ *   2007-2018 by Peter Semiletov                                          *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,20 +18,26 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#ifdef H_DEPRECATED
+#include <string>
+#include <vector>
+#endif
+
 #ifdef HUNSPELL_ENABLE
 #include <hunspell/hunspell.hxx>
 #endif
 
+#include <QTextCodec>
+#include <QDir>
+#include <QRegExp>
+
+
 #ifdef SPELLCHECK_ENABLE
 #include "spellchecker.h"
 #endif
 
 #include "utils.h"
 
-#include <QTextCodec>
-#include <QDir>
-#include <QRegExp>
-
 
 
 #ifdef ASPELL_ENABLE
@@ -213,7 +219,7 @@ QStringList CSpellchecker::get_suggestions_list (const QString &word)
 
 CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, const QString &user_path): ASpellchecker (lang, path, user_path)
 {
-  qDebug() << "CHunspellChecker::CHunspellChecker - start";
+//  qDebug() << "CHunspellChecker::CHunspellChecker - start";
 
   initialized = false;
 
@@ -221,16 +227,17 @@ CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, co
   user_dir = user_path; 
   lng = lang;
 
-
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 
   QString fname_aff = path + QDir::separator() + lng + ".aff";
   QString fname_dict = path + QDir::separator() + lng + ".dic";
   QString fname_userdict = user_path + QDir::separator() + lng + ".dic";
+  QString fname_userdict_pure; 
 
   fname_aff = fname_aff.replace ("/", "\\");
   fname_dict = fname_dict.replace ("/", "\\");
   fname_userdict = fname_userdict.replace ("/", "\\");
+  fname_userdict_pure = fname_userdict;
 
 #else
 
@@ -249,39 +256,38 @@ CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, co
 
 #endif
 
-
 //qDebug() << fname_aff;
 //qDebug() << fname_dict;
 //qDebug() << fname_userdict;
 
+  if (dir_exists (dict_dir)) 
+     initialized = true;
 
   speller = new Hunspell (fname_aff.toUtf8().data(), fname_dict.toUtf8().data());
   encoding = speller->get_dic_encoding();
 
-
-//    const char *c_aff = fname_aff.toLocal8Bit().constData();
-  //  const char *c_dict = fname_dict.toLocal8Bit().constData();
-
-//    speller = new Hunspell (c_aff, c_dict);
-
+#if defined(Q_OS_UNIX)
   
+  if (initialized)
   if (file_exists (fname_userdict))
      {
       speller->add_dic (fname_userdict.toUtf8().data());
       user_words = qstring_load (fname_userdict, encoding).split ("\n");
       user_words.removeFirst();
-     } 
+     }
+#else
 
+  if (initialized)
+  if (file_exists (fname_userdict_pure))
+     {
+      speller->add_dic (fname_userdict.toUtf8().data());
+      user_words = qstring_load (fname_userdict, encoding).split ("\n");
+      user_words.removeFirst();
+     }
 
-  initialized = true;
-
-//  if (file_exists (fname_dict))
-  //    initialized = true;
-//  else
-  //    qDebug() << "Hunspell engine is not initilized with a proper dictionary file " << fname_dict;
-
-  qDebug() << "CHunspellChecker::CHunspellChecker - end";
+#endif
 
+//  qDebug() << "CHunspellChecker::CHunspellChecker - end";
 }
 
 
@@ -313,50 +319,52 @@ void CHunspellChecker::change_lang (const QString &lang)
   delete speller;
 
   initialized = false;
-
   lng = lang;
-
   user_words.clear(); 
 
+  if (dir_exists (dict_dir)) 
+     initialized = true;
+
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 
   QString fname_aff = dict_dir + QDir::separator() + lng + ".aff";
   QString fname_dict = dict_dir + QDir::separator() + lng + ".dic";
   QString fname_userdict = user_dir + QDir::separator() + lng + ".dic";
+  QString fname_userdict_pure;
 
- fname_aff = fname_aff.replace ("/", "\\");
- fname_dict = fname_dict.replace ("/", "\\");
- fname_userdict = fname_userdict.replace ("/", "\\");
-
-
+  fname_aff = fname_aff.replace ("/", "\\");
+  fname_dict = fname_dict.replace ("/", "\\");
+  fname_userdict = fname_userdict.replace ("/", "\\");
+  fname_userdict_pure = fname_userdict;
+  
 #else
 
   QString fname_aff = dict_dir + QDir::separator() + lng + ".aff";
   QString fname_dict = dict_dir + QDir::separator() + lng + ".dic";
   QString fname_userdict = user_dir + QDir::separator() + lng + ".dic";
 
-
 #endif
 
   speller = new Hunspell (fname_aff.toUtf8().data(), fname_dict.toUtf8().data());
   encoding = speller->get_dic_encoding();
 
-  if (file_exists (fname_userdict))
+#if defined(Q_OS_UNIX)
+
+  if (initialized && file_exists (fname_userdict))
      {
       speller->add_dic (fname_userdict.toUtf8().data());
       user_words = qstring_load (fname_userdict, encoding).split ("\n");  
       user_words.removeFirst(); //зачем я это закомментировал раньше?
-     } 
-
-  initialized = true;
-
-//  qDebug() << "encoding: " << QString (encoding);
-/*  if (file_exists (fname_dict))
-      initialized = true;
-  else
-      qDebug() << "Hunspell engine is not initilized with a proper dictionary file " << fname_dict;
-
-  qDebug() << "restarting hunspell with " << fname_aff << " " << fname_dict;*/
+     }
+#else
+  if (initialized && file_exists (fname_userdict_pure))
+     {
+      speller->add_dic (fname_userdict.toUtf8().data());
+      user_words = qstring_load (fname_userdict, encoding).split ("\n");  
+      user_words.removeFirst(); //зачем я это закомментировал раньше?
+     }
+     
+#endif     
 }
 
 
@@ -377,10 +385,14 @@ bool CHunspellChecker::check (const QString &word)
   if (! initialized)
       return false;
 
-  QTextCodec *codec = QTextCodec::codecForName (encoding);
-  QByteArray es = codec->fromUnicode (word);
+ QTextCodec *codec = QTextCodec::codecForName (encoding);
+ QByteArray es = codec->fromUnicode (word);
  
-  return speller->spell (es.data());
+#ifndef H_DEPRECATED
+  return speller->spell (es.data()); //old way
+#else  
+  return speller->spell (QString(es).toStdString());
+#endif
 }
 
 
@@ -400,10 +412,13 @@ void CHunspellChecker::remove_from_user_dict (const QString &word)
 
 QStringList CHunspellChecker::get_speller_modules_list()
 {
+  QStringList sl;
+  
   QDir dir (dict_dir);
+  if (! dir.exists())
+     return sl;
 
   QStringList filters;
-  QStringList sl;
   
   filters << "*.dic";
   
@@ -421,25 +436,33 @@ QStringList CHunspellChecker::get_speller_modules_list()
 
 QStringList CHunspellChecker::get_suggestions_list (const QString &word)
 {
-//  if (! initialized)
-  //   return QStringList();
-
   QStringList sl;
 
-  if (word.isEmpty())
+  if (! initialized || word.isEmpty())
      return sl;
 
   QTextCodec *codec = QTextCodec::codecForName (encoding);
   QByteArray es = codec->fromUnicode (word);
 
+#ifndef H_DEPRECATED
   char **slst;
     
-  int size = speller->suggest(&slst, es.data());
+  int size = speller->suggest (&slst, es.data());
   
   for (int i = 0; i < size; i++)
       sl.append (codec->toUnicode (slst[i]));
    
   speller->free_list (&slst, size);
+
+#else
+
+  std::vector<std::string> suglist = speller->suggest (QString(es).toStdString());
+
+  sl.reserve (suglist.size());
+  for (size_t i = 0, sz = suglist.size(); i < sz; ++i)
+      sl.append (QString::fromStdString (suglist[i]));        
+
+#endif
   
   return sl;
 }
