@@ -45,10 +45,6 @@ DJVU read code taken fromdvutxt.c:
 //C- +------------------------------------------------------------------
 */
 
-#include "tio.h"
-#include "utils.h"
-#include "tzipper.h"
-
 #include <QXmlStreamReader>
 #include <QTextStream>
 #include <QDebug>
@@ -63,7 +59,6 @@ DJVU read code taken fromdvutxt.c:
 
 
 #ifdef DJVU_ENABLE
-
 #include <stddef.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -71,19 +66,18 @@ DJVU read code taken fromdvutxt.c:
 #include <locale.h>
 #include <fcntl.h>
 #include <errno.h>
-
-#include "libdjvu/miniexp.h"
-#include "libdjvu/ddjvuapi.h"
-
+#include <libdjvu/miniexp.h>
+#include <libdjvu/ddjvuapi.h>
 #endif
 
 
+#include "tio.h"
+#include "utils.h"
+#include "tzipper.h"
+
 
 bool CTioPlainText::load (const QString &fname)
 {
-
- //qDebug() << "EOL detection - start";
-
   QFile feol_detector (fname);
 
   if (! feol_detector.open (QFile::ReadOnly))
@@ -99,23 +93,21 @@ bool CTioPlainText::load (const QString &fname)
   if (block.indexOf ("\r\n") != -1)
      eol = "\r\n";
   else
-      {
-       if (block.indexOf ('\n') != -1)
-          eol = "\n";
-       else
-           if (block.indexOf ('\r') != -1)
-              eol = "\r";
-      }   
-  /*
+  if (block.indexOf ('\n') != -1)
+     eol = "\n";
+  else
+  if (block.indexOf ('\r') != -1)
+     eol = "\r";
+        
+/*  
    if (eol == "\n")
      qDebug() << "LF";
    if (eol == "\r\n")
      qDebug() << "CRLF";
    if (eol == "\r")
      qDebug() << "CR";
-
-  qDebug() << "EOL detection - end";
 */
+
   feol_detector.close();
 
   QFile file (fname);
@@ -160,6 +152,7 @@ bool CTioPlainText::save (const QString &fname)
 CTioHandler::CTioHandler()
 {
   default_handler = new CTioPlainText;
+  
   list.append (default_handler);
   list.append (new CTioGzip);
   list.append (new CTioXMLZipped);
@@ -179,7 +172,6 @@ CTioHandler::CTioHandler()
   list.append (new CTioDJVU);
     
 #endif    
-
 }
 
 
@@ -229,7 +221,7 @@ bool CTioGzip::load (const QString &fname)
 
 bool CTioReadOnly::save (const QString &fname)
 {
-  error_string = tr ("saving of this format is not supported");
+  error_string = tr ("Saving for this format is not supported");
   return false;
 }
 
@@ -269,11 +261,11 @@ bool CTioABW::load (const QString &fname)
             {
              QString s = xml.text().toString();
              if (! s.isEmpty())
-               {
-                data.append (xml.text().toString());
-                data.append("\n");
-               }
-             }
+                {
+                 data.append (s);
+                 data.append("\n");
+                }
+            }
         }
 
    if (xml.hasError())
@@ -285,7 +277,6 @@ bool CTioABW::load (const QString &fname)
 
 bool CTioODTSpecial::load (const QString &fname)
 {
-
   data.clear();
   
   CZipper zipper;
@@ -325,7 +316,6 @@ bool CTioODTSpecial::load (const QString &fname)
              if (tag_name.startsWith ("text") && tag_name != "text:span")
                 tt = true;
             }
-      
          
          if (xml.isCharacters() && tt)
             {
@@ -408,7 +398,7 @@ bool CTioXMLZipped::load (const QString &fname)
              QString s = xml.text().toString();
              if (! s.isEmpty())
                {
-                data.append (xml.text().toString());
+                data.append (s);
                 data.append("\n");
                }
              }
@@ -430,8 +420,10 @@ CCharsetMagic::CCharsetMagic()
   
   foreach (QString fn, fnames)
           {
-           QString fname (":/encsign");
-           fname.append ("/").append (fn);
+           QString fname = ":/encsign";
+           fname.append ("/"); 
+           fname.append (fn); 
+           
            QByteArray a = file_load (fname);     
            QList<QByteArray> bsl = a.split ('\n'); 
   
@@ -506,6 +498,8 @@ bool CTioFB2::load (const QString &fname)
   data.clear();
 
   QByteArray ba = file_load (fname);
+  if (ba.isEmpty())
+     return false;
 
   //read encoding:
 
@@ -514,65 +508,64 @@ bool CTioFB2::load (const QString &fname)
   if (enc.isEmpty())
      enc = "UTF-8";
 
-   QTextCodec *codec = QTextCodec::codecForName (enc.toLatin1().data());
-   QString temp = codec->toUnicode (ba);
+  QTextCodec *codec = QTextCodec::codecForName (enc.toLatin1().data());
+  QString temp = codec->toUnicode (ba);
 
-   QString ts = "p";
+  QString ts = "p";
 
-   QXmlStreamReader xml (temp);
+  QXmlStreamReader xml (temp);
 
-   bool tt = false;
-   bool title = false;
-   bool section = false;
+  bool tt = false;
+  bool title = false;
+  bool section = false;
 
-   while (! xml.atEnd())
-         {
-          xml.readNext();
+  while (! xml.atEnd())
+        {
+         xml.readNext();
 
-          QString tag_name = xml.qualifiedName().toString().toLower();
+         QString tag_name = xml.qualifiedName().toString().toLower();
 
-           if (xml.isStartElement())
-              {
-               if (tag_name == ts)
-                  tt = true;
+         if (xml.isStartElement())
+            {
+             if (tag_name == ts)
+                tt = true;
 
-               if (tag_name == "title")
-                  title = true;
+             if (tag_name == "title")
+                title = true;
 
-               if (tag_name == "section")
-                  section = true;
+             if (tag_name == "section")
+                section = true;
+            }
 
-              }
-
-           if (xml.isEndElement())
-              {
-               if (tag_name == ts)
+         if (xml.isEndElement())
+            {
+             if (tag_name == ts)
                  tt = false;
 
-               if (tag_name == "title")
-                 {
-                  title = false;
-                  data.append("\n");
-                 }
+             if (tag_name == "title")
+                {
+                 title = false;
+                 data.append("\n");
+                }
 
-               if (tag_name == "section")
-                 {
-                  section = false;
-                  data.append("\n");
-                 }
-              }
+             if (tag_name == "section")
+                {
+                 section = false;
+                 data.append("\n");
+                }
+             }
 
-           if (tt && xml.isCharacters())
-              {
-               QString s = xml.text().toString();
-               if (! s.isEmpty())
-                 {
-                  data.append ("   ");
-                  data.append (s);
-                  data.append("\n");
-                 }
-               }
-          }
+         if (tt && xml.isCharacters())
+            {
+             QString s = xml.text().toString();
+             if (! s.isEmpty())
+                {
+                 data.append ("   ");
+                 data.append (s);
+                 data.append("\n");
+                }
+            }
+        }
 
   if (xml.hasError())
     qDebug() << "xml parse error";
@@ -870,10 +863,10 @@ void dopage (int pageno)
   
   const char *lvl = (detail) ? detail : "page";
   
-  while ((r = ddjvu_document_get_pagetext (doc, pageno/* - 1*/, lvl)) == miniexp_dummy)
+  while ((r = ddjvu_document_get_pagetext (doc, pageno, lvl)) == miniexp_dummy)
          djvumsg_handle();
 
-  if ((r = miniexp_nth (5, r)) && miniexp_stringp(r))
+  if ((r = miniexp_nth (5, r)) && miniexp_stringp (r))
      {
       const char *s = miniexp_to_str (r); 
       if (s)
@@ -894,17 +887,17 @@ CTioDJVU::CTioDJVU()
 
 bool CTioDJVU::load (const QString &fname)
 {
-
-  if (! (ctx = ddjvu_context_create("tea")))
+  if (! (ctx = ddjvu_context_create ("tea")))
      return false;
      
-  if (! (doc = ddjvu_document_create_by_filename(ctx, fname.toUtf8().data(), TRUE)))
-    return false;
+  if (! (doc = ddjvu_document_create_by_filename (ctx, fname.toUtf8().data(), TRUE)))
+     return false;
 
     
-  while (! ddjvu_document_decoding_done(doc))
+  while (! ddjvu_document_decoding_done (doc))
         djvumsg_handle();
 
+
   int n = ddjvu_document_get_pagenum (doc);
   
   for (int i = 0; i < n; i++)
