@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de_DE" sourcelanguage="en">
+<TS version="2.1" language="de_DE" sourcelanguage="en">
 <context>
     <name>CAboutWindow</name>
     <message>
@@ -1352,10 +1352,6 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Refresh labels</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Add user font</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Label starts with: </source>
         <translation type="unfinished"></translation>
@@ -1364,14 +1360,6 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Label ends with: </source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Select font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Fonts (*.ttf *.otf)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>C++ template</source>
         <translation type="unfinished"></translation>
@@ -1809,5 +1797,21 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Apply template</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Compare two strings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use joystick as cursor keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>There is no stylesheet file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cannot save: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
