@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fr_FR" sourcelanguage="en">
+<TS version="2.1" language="fr_FR" sourcelanguage="en">
 <context>
     <name>CAboutWindow</name>
     <message>
@@ -1493,10 +1493,6 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>Unpack ZIP to current directory</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Add user font</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Northern hemisphere</source>
         <translation type="unfinished"></translation>
@@ -1565,14 +1561,6 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>Select the file name first!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Select font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Fonts (*.ttf *.otf)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>%1 kbytes %2 &lt;br&gt;</source>
         <translation type="unfinished"></translation>
@@ -1902,5 +1890,21 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>Apply template</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Compare two strings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use joystick as cursor keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>There is no stylesheet file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cannot save: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
